@@ -1,6 +1,8 @@
 package ArangoDB::Constants;
 use strict;
 use warnings;
+use utf8;
+use 5.008001;
 use parent qw(Exporter);
 
 my @options = qw(OPTION_ENDPOINT OPTION_HOST OPTION_PORT OPTION_PILICY OPTION_WAIT_SYNC OPTION_AUTH_USER
