@@ -1,6 +1,8 @@
 package ArangoDB::Cursor;
 use strict;
 use warnings;
+use utf8;
+use 5.008001;
 use Carp qw(croak);
 use Scalar::Util qw(weaken);
 use ArangoDB::Document;
@@ -55,6 +57,17 @@ sub next {
     return;
 }
 
+sub all {
+    my $self = shift;
+    my @result;
+    while ( !@result || $self->_get_next_batch() ) {
+        my $last = $self->{length} -1;
+        push @result, ( @{ $self->{result} } )[ 0 .. $last ];
+    }
+    my $conn = $self->{connection};
+    return [ map { ArangoDB::Document->new( $conn, $_ ) } @result ];
+}
+
 sub _get_next_batch {
     my $self = shift;
     return unless $self->{has_more};
@@ -123,6 +136,10 @@ Constructor.
 
 Returns next document(Instance of L<ArangoDB::Document>).
 
+=head2 all()
+
+Rreturns all documents in the cursor.(ARRAY reference)
+
 =head2 delete()
 
 Delete cursor.
